##  Documentation
For detailed information on how to install and use the adapter, visit [LeanIX Adapter for SAP Integration Suite![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fapi.sap.com%2Fpackage%2FLeanIXAdapterforSAPIntegrationSuite%2Fdocuments "https://api.sap.com/package/LeanIXAdapterforSAPIntegrationSuite/documents") on SAP Business Accelerator Hub. On the Documents tab, you’ll find documentation and release notes.
YesNo
Send
